==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translatorcomment>--google--
Przyciągaj do punktów centralnych</translatorcomment>
        <translation type="unfinished">Srodek</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation type="unfinished">Punkt odniesienia</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translatorcomment>--google--
Wskaż punkt docelowy</translatorcomment>
        <translation type="unfinished">Punkt docelowy</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Obracaj</translatorcomment>
        <translation type="unfinished">&amp;Obracaj</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Opcje przesuwania/obrotów
Opcje przesuwania/obracania</translatorcomment>
        <translation type="unfinished">Opcje obrotów</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba kopii
Wprowadź liczbę kopii</translatorcomment>
        <translation type="unfinished">Liczba kopii</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń oryginał</translatorcomment>
        <translation type="unfinished">&amp;Usuń oryginał</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zachowaj oryginał</translatorcomment>
        <translation type="unfinished">&amp;Zachowaj oryginał</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kopie &amp;wielokrotne
Kopie &amp;wielokrotne:</translatorcomment>
        <translation type="unfinished">Kopie &amp;wielokrotne</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Kąt (a):</translatorcomment>
        <translation type="unfinished">&amp;Kąt (a):</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Użyj bieżącej warstwy i atrybuty</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translatorcomment>--google--
Przyciągaj do punktów centralnych</translatorcomment>
        <translation>Środek</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation>Punkt odniesienia</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translatorcomment>--google--
Wskaż punkt docelowy</translatorcomment>
        <translation>Punkt docelowy</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Obracaj</translatorcomment>
        <translation>&amp;Obróć</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Opcje przesuwania/obrotów
Opcje przesuwania/obracania</translatorcomment>
        <translation>Opcje obracania</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba kopii
Wprowadź liczbę kopii</translatorcomment>
        <translation>Liczba kopii</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń oryginał</translatorcomment>
        <translation>&amp;Usunięcie oryginału</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zachowaj oryginał</translatorcomment>
        <translation>&amp;Zachowanie oryginału</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kopie &amp;wielokrotne
Kopie &amp;wielokrotne:</translatorcomment>
        <translation>&amp;Wielokrotne skopiowanie</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Kąt (a):</translatorcomment>
        <translation>&amp;Kąt (a):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Define angle using mouse cursor</source>
        <translation>Określ kąt za pomocą wskaźnika myszy</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Użycie aktualnej warstwy i &amp;atrybutów</translation>
    </message>
</context>
</TS>
